@@ -1,28 +1,31 @@
 use strict;
 use warnings;
-package Test::Deep::YAML;
-BEGIN {
-  $Test::Deep::YAML::AUTHORITY = 'cpan:ETHER';
-}
-# git description: v0.001-13-gc7b3f74
-$Test::Deep::YAML::VERSION = '0.002';
+package Test::Deep::YAML; # git description: v0.002-16-ge7eb62a
 # ABSTRACT: A Test::Deep plugin for comparing YAML-encoded data
-# vim: set ts=8 sw=4 tw=78 et :
+# KEYWORDS: testing tests plugin YAML data
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+
+our $VERSION = '0.003';
 
-use parent 'Test::Deep::Cmp';
 use Exporter 'import';
-use Test::Deep;
-use Try::Tiny;
-use YAML 'Load';
 
 our @EXPORT = qw(yaml);
 
 sub yaml
 {
     my ($expected) = @_;
-    return __PACKAGE__->new($expected);
+    return Test::Deep::YAML::Object->new($expected);
 }
 
+package # hide from PAUSE
+    Test::Deep::YAML::Object;
+
+our $VERSION = '0.003';
+
+use parent 'Test::Deep::Cmp';
+use Try::Tiny ();
+use YAML ();
+
 sub init
 {
     my ($self, $expected) = @_;
@@ -33,11 +36,11 @@ sub descend
 {
     my ($self, $got) = @_;
 
-    my $data = try
+    my $data = Try::Tiny::try
     {
-         Load($got);
+        YAML::Load($got);
     }
-    catch
+    Try::Tiny::catch
     {
         chomp($self->{error_message} = $_);
         undef;
@@ -63,15 +66,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Karen Etheridge yaml irc
-
 =head1 NAME
 
 Test::Deep::YAML - A Test::Deep plugin for comparing YAML-encoded data
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -87,6 +88,8 @@ version 0.002
 
 =head1 DESCRIPTION
 
+=for stopwords yaml
+
 This module provides the C<yaml> function to indicate that the target can be
 parsed as a YAML string, and should be decoded before being compared to the
 indicated expected data.
@@ -102,6 +105,8 @@ after it has been YAML-decoded.
 
 =head1 SUPPORT
 
+=for stopwords irc
+
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Deep-YAML>
 (or L<bug-Test-Deep-YAML@rt.cpan.org|mailto:bug-Test-Deep-YAML@rt.cpan.org>).
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
